@@ -79,7 +79,8 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
 
         RUN,
         TERMINATE,
-        ABORT
+        ABORT,
+	ABORTING
     }
     private final static String TERMINATE = "TERMINATE";
     private final static String ABORT = "ABORT";
@@ -672,6 +673,7 @@ public class GmplSwing implements Runnable, GlpkTerminalListener,
             GlpkTerminal.removeAllListeners();
 
             try {
+	        terminate = Status.ABORTING;
                 GLPK.glp_java_error("Aborting due to user request");
             } catch (GlpkException ex) {
             } finally {
