@@ -12,24 +12,20 @@ void glp_java_error(char *message);
 void glp_java_set_msg_lvl(int msg_lvl);
 void glp_java_set_numeric_locale(const char *locale);
 
-typedef struct _glp_java_arc_data glp_java_arc_data;
-
-struct _glp_java_arc_data {
+typedef struct {
    double cap;  // arc capacity
    double cost; // arc cost
    double low;  // lower bound
    double rc;   // reduced cost
    double x;    // arc flow
-};
+} glp_java_arc_data;
 
-typedef struct _glp_java_vertex_data glp_java_vertex_data;
-
-struct _glp_java_vertex_data {
+typedef struct  {
    int    cut; // 0: node is unlabeled, 1: node is labeled
    double pi;  // node potential
    double rhs; // supply/demand value
    int    set; // 0: vertex is in set R, 1: vertex is in set S
-};
+} glp_java_vertex_data;
 
 glp_java_arc_data *glp_java_arc_get_data(const glp_arc *arc);
 glp_java_vertex_data *glp_java_vertex_data_get( const glp_graph *G, const int i);
@@ -37,13 +33,13 @@ glp_java_vertex_data *glp_java_vertex_get_data( const glp_vertex *v);
 glp_vertex *glp_java_vertex_get( const glp_graph *G, const int i );
 
 struct glp_prob {
-   double _opaque_prob[100];
+    int hidden_internal;
 };
 struct glp_tran {
-   double _opaque_tran[100];
+    int hidden_internal;
 };
 struct glp_tree {
-   double _opaque_tree[100];
+    int hidden_internal;
 };
 
 #endif // GLPK_JAVA_H
